pub fn build_script()Expand description
Function that must be called inside the cargo build script to set up the lockjaw environment in a binary crate.
lockjaw should be added to [build-dependencies] of the crate.
// build.rs
fn main() {
lockjaw::build_script();
}